#!/bin/sh
#
# Create a dummy libGL.so that is useful for linking, but not runtime

SYSTEM_LIBGL="/usr/lib/x86_64-linux-gnu/mesa/libGL.so"
DUMMY_SOURCE="$1"

if [ -z "$DUMMY_SOURCE" ]; then
	echo "Usage: $0 <output>"
	exit 1
fi

if [ ! -f "$SYSTEM_LIBGL" ]; then
	echo "Missing OpenGL library: $SYSTEM_LIBGL"
	exit 2
fi

cat >"$DUMMY_SOURCE" <<__EOF__
/* AUTOGENERATED by $0, do not edit! */
/*
 * This is a list of symbols for the linker to find
 */
__EOF__

nm -D "$SYSTEM_LIBGL" | grep " T " | egrep -v '_init|_fini' | awk '{print $3}' | sort | uniq |
while read symbol; do
	echo "void $symbol() { }" >>"$DUMMY_SOURCE"
done
